Coverage for /Users/davegaeddert/Development/dropseed/plain/plain/plain/preflight/__init__.py: 100%

1 from .messages import (

2 CRITICAL,

3 DEBUG,

4 ERROR,

5 INFO,

6 WARNING,

7 CheckMessage,

8 Critical,

9 Debug,

10 Error,

11 Info,

12 Warning,

13)

14 from .registry import register, run_checks

15

16# Import these to force registration of checks

17 import plain.preflight.files # NOQA isort:skip

18 import plain.preflight.security.base # NOQA isort:skip

19 import plain.preflight.security.csrf # NOQA isort:skip

20 import plain.preflight.urls # NOQA isort:skip

21

22

23 __all__ = [

24 "CheckMessage",

25 "Debug",

26 "Info",

27 "Warning",

28 "Error",

29 "Critical",

30 "DEBUG",

31 "INFO",

32 "WARNING",

33 "ERROR",

34 "CRITICAL",

35 "register",

36 "run_checks",

37]